@@ -1,13 +1,22 @@
 /* Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * This file is part of pdf2djvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
-#include <clocale>
-
 #include "i18n.hh"
+
+#include <clocale>
+#include <string>
+
 #include "paths.hh"
 #include "system.hh"
 
