@@ -1,3 +1,17 @@
+/* Copyright © 2015-2016 Jakub Wilk <jwilk@jwilk.net>
+ *
+ * This file is part of pdf2djvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ */
+
 #include "pdf-document-map.hh"
 
 #include <algorithm>
@@ -14,30 +28,22 @@ pdf::DocumentMap::DocumentMap(const std::vector<const char *> &paths)
 {
     int global_index = 0;
     this->byte_size = 0;
-    for (std::vector<const char*>::const_iterator it = paths.begin(); it != paths.end(); it++)
+    for (const char *path : paths)
     {
         this->indices.push_back(global_index);
         {
-            std::ifstream ifs(*it, std::ifstream::in | std::ifstream::binary);
+            std::ifstream ifs(path, std::ifstream::in | std::ifstream::binary);
             ifs.seekg(0, std::ios::end);
             this->byte_size += ifs.tellg();
             ifs.close();
         }
         {
-            std::auto_ptr<pdf::Document> doc(new pdf::Document(*it));
+            std::unique_ptr<pdf::Document> doc(new pdf::Document(path));
             pdf::Catalog *catalog = doc->getCatalog();
             for (int i = 0; i < doc->getNumPages(); i++) {
                 pdf::String s;
                 if (catalog->indexToLabel(i, &s)) {
                     std::string str = pdf::string_as_utf8(&s);
-#if POPPLER_VERSION < 1903
-                    // Prior to 0.19.3, Poppler incorrectly adds trailing
-                    // NULL character to Unicode labels:
-                    // https://cgit.freedesktop.org/poppler/poppler/commit/?id=cef6ac0ebbf8
-                    // Let's strip it.
-                    if (str.length() > 0 && str.end()[-1] == '\0')
-                        str.erase(str.end() - 1);
-#endif
                     this->labels.push_back(str);
                 }
                 else
