@@ -73,20 +73,6 @@ public:
   { }
 };
 
-// for POPPLER_VERSION < 8600
-template <typename T>
-void unique_reset(std::unique_ptr<T> &up, T* ptr)
-{
-  up.reset(ptr);
-}
-
-// for POPPLER_VERSION >= 8600
-template <typename T>
-void unique_reset(std::unique_ptr<T> &up, std::unique_ptr<T> ptr)
-{
-  up = std::move(ptr);
-}
-
 static int get_page_for_goto_link(pdf::link::GoTo *goto_link, pdf::Catalog *catalog)
 {
   std::unique_ptr<pdf::link::Destination> dest;
@@ -95,7 +81,13 @@ static int get_page_for_goto_link(pdf::link::GoTo *goto_link, pdf::Catalog *cata
 #endif
   pdf::link::Destination *orig_dest = goto_link->getDest();
   if (orig_dest == nullptr)
-    unique_reset(dest, catalog->findDest(goto_link->getNamedDest()));
+  {
+#if POPPLER_VERSION >= 8600
+    dest = catalog->findDest(goto_link->getNamedDest());
+#else
+    dest.reset(catalog->findDest(goto_link->getNamedDest()));
+#endif
+  }
   else
     dest.reset(orig_dest->copy());
   if (dest.get() != nullptr)
@@ -483,7 +475,11 @@ public:
     switch (link_action->getKind())
     {
     case actionURI:
+#if POPPLER_VERSION >= 8600
+      uri = dynamic_cast<pdf::link::URI*>(link_action)->getURI();
+#else
       uri += pdf::get_c_string(dynamic_cast<pdf::link::URI*>(link_action)->getURI());
+#endif
       break;
     case actionGoTo:
     {
@@ -722,9 +718,21 @@ static void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog
         pdf::OwnedObject destination;
         std::unique_ptr<pdf::link::Action> link_action;
         if (!pdf::dict_lookup(current, "Dest", &destination)->isNull())
+        {
+#if POPPLER_VERSION >= 8600
+          link_action = pdf::link::Action::parseDest(&destination);
+#else
           link_action.reset(pdf::link::Action::parseDest(&destination));
+#endif
+        }
         else if (!pdf::dict_lookup(current, "A", &destination)->isNull())
+        {
+#if POPPLER_VERSION >= 8600
+          link_action = pdf::link::Action::parseAction(&destination);
+#else
           link_action.reset(pdf::link::Action::parseAction(&destination));
+#endif
+        }
         else
           throw NoPageForBookmark();
         if (link_action.get() == nullptr || link_action->getKind() != actionGoTo)
