@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,15 +13,15 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
 import unicodedata
 
 from tools import (
     case,
-    re,
 )
 
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/90
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/90
     # + fixed in 0.8
 
     text = u'\N{LATIN SMALL LIGATURE FL}uorogra\N{LATIN SMALL LIGATURE FI}a'
@@ -31,11 +31,11 @@ class test(case):
     def test_nfkc(self):
         self.pdf2djvu().assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^{s} *$'.format(s=self.text_nfkc), re.M))
+        r.assert_(stdout=re.compile('^{s} *$'.format(s=self.text_nfkc), re.M))
 
     def test_no_nfkc(self):
         self.pdf2djvu('--no-nfkc').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^{s} *$'.format(s=self.text_nfkc), re.M))
+        r.assert_(stdout=re.compile('^{s} *$'.format(s=self.text_nfkc), re.M))
 
 # vim:ts=4 sts=4 sw=4 et
