@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,14 +13,15 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     case,
-    re,
 )
 
 class test(case):
-    # + fixed in 0.4.9 [18b2ae04de2f]
-    # + fixed in 0.4.11 [fa7d4addf18e]
+    # + fixed in 0.4.9 [8af81b21de1d8c43bb7585b5318938cde52e30a2]
+    # + fixed in 0.4.11 [670a11dc9680cb4dac088d269f08f16f8ec0da7c]
 
     text = u'¾'
     text_nfkc = '3⁄4'
@@ -29,11 +30,11 @@ class test(case):
     def test_nfkc(self):
         self.pdf2djvu().assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^{s} *$'.format(s=self.text_nfkc), re.M))
+        r.assert_(stdout=re.compile('^{s} *$'.format(s=self.text_nfkc), re.M))
 
     def test_no_nfkc(self):
         self.pdf2djvu('--no-nfkc').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^{s} *$'.format(s=self.text_no_nfkc), re.M))
+        r.assert_(stdout=re.compile('^{s} *$'.format(s=self.text_no_nfkc), re.M))
 
 # vim:ts=4 sts=4 sw=4 et
